%define		major		2.3
%define		libname		%mklibname opencolorio %{major}
%define		develname	%mklibname opencolorio -d

# WARNING: OpenColorIO and OpenImageIO are cross dependent.
# If an ABI incompatible update is done in one, the other also needs to be rebuilt.
%bcond_without	openimageio

%ifarch x86_64
%bcond_with check
%else
%bcond_with check
%endif

Name:		opencolorio
Version:	2.3.1
Release:	%mkrel 2
Summary:	A complete color management solution
Group:		System/Libraries
License:	BSD
URL:		https://opencolorio.org/
Source0:	https://github.com/AcademySoftwareFoundation/OpenColorIO/archive/v%{version}/OpenColorIO-%{version}.tar.gz
## Upstream patches:
#
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	boost-devel
BuildRequires:	pybind11-devel
BuildRequires:	cmake(pystring)
BuildRequires:	pkgconfig(Imath)
BuildRequires:	pkgconfig(lcms2)
BuildRequires:	pkgconfig(tinyxml)
BuildRequires:	pkgconfig(yaml-cpp)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(minizip-ng)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3dist(markupsafe)
%if %{with openimageio}
BuildRequires:	pkgconfig(OpenImageIO)
BuildRequires:	openimageio
%endif

%description
OpenColorIO (OCIO) is a complete color management solution geared towards
motion picture production with an emphasis on visual effects and computer
animation. OCIO provides a straightforward and consistent user experience
across all supporting applications while allowing for sophisticated
back-end configuration options suitable for high-end production usage.
OCIO is compatible with the Academy Color Encoding Specification (ACES)
and is LUT-format agnostic, supporting many popular formats.

%package -n %{libname}
Summary:	A complete color management solution
Group:		System/Libraries

%description -n %{libname}
A complete color management solution.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name} library.

%package -n python3-pyopencolorio
Summary:	Python 3 Bindings for %{name}
Group:		Development/Python

%description -n python3-pyopencolorio
This package contains python 3 bindings for %{name}.

%prep
%autosetup -n OpenColorIO-%{version} -p1

%build
%cmake -GNinja \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DCMAKE_SKIP_INSTALL_RPATH=ON \
	-DOCIO_BUILD_APPS=%{?with_openimageio:ON}%{?!with_openimageio:OFF} \
	-DOCIO_BUILD_NUKE=OFF \
	-DOCIO_BUILD_PYTHON=ON \
	-DOCIO_BUILD_TESTS=%{?with_check:ON}%{?!with_check:OFF} \
	-DOCIO_BUILD_GPU_TESTS=OFF \
%ifnarch x86_64
	-DOCIO_USE_SIMD=OFF \
%endif
	-DOCIO_USE_GLVND=ON \
	-DOpenGL_GL_PREFERENCE=GLVND
%cmake_build

%install
%cmake_install

%if %{with check}
%check
%ctest
%endif

%files
%doc CHANGELOG.md README.md
%license LICENSE
%if %{with openimageio}
%{_bindir}/*
%endif
%{_datadir}/ocio/

%files -n %{libname}
%{_libdir}/libOpenColorIO.so.%{major}
%{_libdir}/libOpenColorIO.so.%{version}

%files -n %{develname}
%{_libdir}/libOpenColorIO.so
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/cmake/OpenColorIO/
%{_includedir}/OpenColorIO/
#
%if %{with openimageio}
%{_libdir}/libOpenColorIOimageioapphelpers.a
%{_libdir}/libOpenColorIOoglapphelpers.a
%endif

%files -n python3-pyopencolorio
%{python3_sitearch}/PyOpenColorIO/


%changelog
* Thu Apr 25 2024 daviddavid <daviddavid> 2.3.1-2.mga10
+ Revision: 2061087
- rebuild for new yaml-cpp 0.8.0

* Thu Jan 18 2024 daviddavid <daviddavid> 2.3.1-1.mga10
+ Revision: 2031943
- new version: 2.3.1
- remove merged upstream patches

* Thu Jan 18 2024 daviddavid <daviddavid> 2.3.0-4.mga10
+ Revision: 2031932
- rebuild for new openimageio 2.5.6.0

* Mon Dec 25 2023 daviddavid <daviddavid> 2.3.0-3.mga10
+ Revision: 2021173
- rebuild for py3.12

* Wed Oct 25 2023 daviddavid <daviddavid> 2.3.0-2.mga10
+ Revision: 2001691
- non-bootstrap build

* Wed Oct 25 2023 daviddavid <daviddavid> 2.3.0-1.mga10
+ Revision: 2001501
- new version: 2.3.0
- rebuild for new minizip-ng 4.0.1

* Sun Jan 01 2023 wally <wally> 2.2.0-3.mga9
+ Revision: 1928493
- build with openimageio 2.4.6.1

* Sat Dec 31 2022 wally <wally> 2.2.0-2.mga9
+ Revision: 1928444
- add upstream patch to fix build on arm

* Sat Dec 31 2022 wally <wally> 2.2.0-1.mga9
+ Revision: 1928426
- new version 2.2.0
- new lib major 2.2

* Tue Dec 27 2022 daviddavid <daviddavid> 2.1.2-3.mga9
+ Revision: 1927188
- non bootstrap build

* Tue Dec 27 2022 daviddavid <daviddavid> 2.1.2-2.mga9
+ Revision: 1927155
- rebuild for new  yaml-cpp 0.7.0

* Wed Oct 12 2022 ghibo <ghibo> 2.1.2-1.mga9
+ Revision: 1896412
- Fix building under gcc12 (Patch2).
- Update to release 2.1.2.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 akien <akien> 2.1.1-3.mga9
+ Revision: 1779143
- Rebuild for python 3.10

* Mon Dec 27 2021 wally <wally> 2.1.1-2.mga9
+ Revision: 1764451
- build using C++14
- rebuild with openimageio

* Sun Dec 26 2021 wally <wally> 2.1.1-1.mga9
+ Revision: 1764088
- new version 2.1.1
- new lib major 2.1
- build without openimageio
- rebuild for openexr 3.1.3

* Mon Jun 07 2021 daviddavid <daviddavid> 2.0.1-2.mga9
+ Revision: 1730075
- fix armh multiple definition build issue

* Mon Jun 07 2021 daviddavid <daviddavid> 2.0.1-1.mga9
+ Revision: 1729975
- new version: 2.0.1
- now libmajor is 2.0

* Thu May 20 2021 daviddavid <daviddavid> 1.1.1-3.mga9
+ Revision: 1725735
- build without '-Werror' compile flags

* Sat Mar 20 2021 daviddavid <daviddavid> 1.1.1-2.mga9
+ Revision: 1705352
- rebuild for python 3.9

* Fri Oct 30 2020 daviddavid <daviddavid> 1.1.1-1.mga8
+ Revision: 1640583
- new version: 1.1.1 (mga#27490)

* Mon Feb 17 2020 umeabot <umeabot> 1.1.0-7.mga8
+ Revision: 1537507
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Oct 31 2019 daviddavid <daviddavid> 1.1.0-6.mga8
+ Revision: 1457154
- rebuild for new yaml-cpp 0.6.3

* Tue Sep 17 2019 daviddavid <daviddavid> 1.1.0-5.mga8
+ Revision: 1442775
- rebuild for python3.8

* Tue Jan 08 2019 tv <tv> 1.1.0-4.mga7
+ Revision: 1352210
- rebuild with python 3.7

* Mon Nov 19 2018 akien <akien> 1.1.0-3.mga7
+ Revision: 1331922
- Rebuild for yaml-cpp 0.6.2

* Sat Sep 29 2018 daviddavid <daviddavid> 1.1.0-2.mga7
+ Revision: 1310911
- add patch to fix build with gcc8
- port the python bindings to python3
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sat May 12 2018 daviddavid <daviddavid> 1.1.0-1.mga7
+ Revision: 1228461
- new version: 1.1.0
- use a named-versioned git tarball
- enable python 2 bindings
- remove merged upstream patches

* Wed Dec 28 2016 wally <wally> 1.0.9-14.mga6
+ Revision: 1078413
- fix pkg names (use lower case)

* Wed Jan 13 2016 pterjan <pterjan> 1.0.9-13.mga6
+ Revision: 922891
- Only use sse2 on x86_64

* Fri Dec 25 2015 daviddavid <daviddavid> 1.0.9-12.mga6
+ Revision: 914616
- rebuild for new boost 1.60.0

* Wed Aug 26 2015 fwang <fwang> 1.0.9-11.mga6
+ Revision: 869487
- update file list
- do not generate cicular deps

* Mon Aug 24 2015 daviddavid <daviddavid> 1.0.9-10.mga6
+ Revision: 868897
- rebuild for new glew 1.13.0

* Tue Jun 23 2015 fwang <fwang> 1.0.9-9.mga6
+ Revision: 840520
- rebuild for new glew

* Wed Oct 15 2014 umeabot <umeabot> 1.0.9-8.mga5
+ Revision: 745822
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.9-7.mga5
+ Revision: 683197
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 akien <akien> 1.0.9-6.mga5
+ Revision: 673528
- Add upstream patch to fix mga#13767

* Mon Sep 01 2014 luigiwalser <luigiwalser> 1.0.9-5.mga5
+ Revision: 670511
- rebuild for glew

* Tue Aug 26 2014 luigiwalser <luigiwalser> 1.0.9-4.mga5
+ Revision: 668356
- rebuild

* Mon Jul 14 2014 akien <akien> 1.0.9-3.mga5
+ Revision: 651806
- Add upstream patch for yaml-cpp 0.5.1 support

* Mon Oct 21 2013 umeabot <umeabot> 1.0.9-2.mga4
+ Revision: 538692
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 fwang <fwang> 1.0.9-1.mga4
+ Revision: 490215
- new version 1.0.9

* Wed Jul 24 2013 sander85 <sander85> 1.0.8-4.mga4
+ Revision: 457720
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 1.0.8-3.mga4
+ Revision: 454652
- rebuild for new openimageio

* Mon Jul 08 2013 fwang <fwang> 1.0.8-2.mga4
+ Revision: 451262
- rebuild for new boost

* Fri Jun 14 2013 fwang <fwang> 1.0.8-1.mga4
+ Revision: 442966
- new version 1.0.8

* Sun Jan 13 2013 umeabot <umeabot> 1.0.7-2.mga3
+ Revision: 361933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 15 2012 fwang <fwang> 1.0.7-1.mga3
+ Revision: 306636
- update file list
- update br
- imported package opencolorio

